Struct SlashingParameters

pub struct SlashingParameters {
    pub destination: Option<Addr>,
    pub max_slashing_bips: u16,
    pub resolution_window: u64,
}

Fields

destination: Option<Addr>

The address to which the slashed funds will be sent after the slashing is finalized.
None, indicates that the slashed funds will be burned.

max_slashing_bips: u16

The maximum percentage of the operator’s total stake that can be slashed.
The value is represented in bips (basis points), where 100 bips = 1%.
And the value must be between 0 and 10_000 (inclusive).

resolution_window: u64

The minimum amount of time (in seconds) that the slashing can be delayed before it is executed and finalized.
Setting this value to a duration less than the queued withdrawal delay is recommended. To prevent restaker’s early withdrawal of their assets from the vault due to the impending slash, defeating the purpose of shared security.

Implementations